==> php83-nextcloud-26.0.5.tgz: share/nextcloud/apps/serverinfo/l10n/sk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Info o CPU nie je dostupné",
    "Load average: {cpu} (last minute)" : "Priemerné zaťaženie:  {cpu} (za poslednú minútu)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Celkom: {memTotalBytes}/Využité: {memUsageBytes}",
    "RAM info not available" : "Informácia o RAM nie je prístupná",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Celkom: {swapTotalBytes}/Využité: {swapUsageBytes}",
    "SWAP info not available" : "Informácia o SWAPe nie je prístupná",
    "Not supported!" : "Nepodporované!",
    "Press ⌘-C to copy." : "Pre kopírovanie, stlačte ⌘-C.",
    "Press Ctrl-C to copy." : "Pre kopírovanie, stlačte Ctrl-C.",
    "System" : "Systém",
    "Monitoring" : "Sledovanie",
    "Monitoring app with useful server information" : "Monitorovacia apka s užitočnými informáciami o serveri",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitočné informácie o serveri, ako napríklad vyťaženie CPU, RAM, využitie diskov, počet používateľov, atď.",
    "Operating System:" : "Operačný systém:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Neznámy procesor",
    "Memory:" : "Pamäť:",
    "Server time:" : "Čas na serveri:",
    "Uptime:" : "Doba behu:",
    "Temperature" : "Teplota",
    "Load" : "Záťaž",
    "Memory" : "Pamäť",
    "Disk" : "Disk",
    "Mount:" : "Prípojný bod:",
    "Filesystem:" : "Súborový systém:",
    "Size:" : "Veľkosť:",
    "Available:" : "Dostupnosť:",
    "Used:" : "Použitie:",
    "You will get a notification once one of your disks is nearly full." : "Ak je niektorý z vašich diskov skoro plný, dostanete varovanie.",
    "Files:" : "Súbory:",
    "Storages:" : "Úložiská:",
    "Free Space:" : "Voľné miesto:",
    "Network" : "Sieť",
    "Hostname:" : "Názov servera:",
    "DNS:" : "DNS:",
    "Gateway:" : "Brána:",
    "Status:" : "Stav:",
    "Speed:" : "Rýchlosť:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktívni užívatelia",
    "Total users:" : "Užívateľov celkom:",
    "Shares" : "Sprístupnené položky",
    "Users:" : "Používatelia:",
    "PHP" : "PHP",
    "Version:" : "Verzia:",
    "Memory limit:" : "Obmedzenie pamäte:",
    "Max execution time:" : "Maximálny čas spustenia:",
    "Upload max size:" : "Maximálna veľkosť pre nahratie:",
    "Extensions:" : "Rozšírenia:",
    "Unable to list extensions" : "Nepodarilo sa zobraziť rozšírenia",
    "Database" : "Databáza",
    "Type:" : "Typ:",
    "External monitoring tool" : "Externý sledovací nástroj",
    "You can connect an external monitoring tool by using this end point:" : "Pre pripojenie externého sledovacieho nástroja použite tento koncový bod:",
    "Copy" : "Kopírovať",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Ak na koniec adresy URL pridáte „?format = json“, získate výsledok v JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Pre používanie prístupového tokenu ho vygenerujte a potom ho nastavte použitím nasledujúceho príkazu:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Pri dotazovaní na vyššie uvedenú adresu URL potom poslať token s hlavičkou „NC-Token“."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> php83-nextcloud-28.0.6.tgz: share/nextcloud/apps/serverinfo/l10n/sk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Info o CPU nie je dostupné",
    "Load average: {cpu} (last minute)" : "Priemerné zaťaženie:  {cpu} (za poslednú minútu)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Celkom: {memTotalBytes}/Využité: {memUsageBytes}",
    "RAM info not available" : "Informácia o RAM nie je prístupná",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Celkom: {swapTotalBytes}/Využité: {swapUsageBytes}",
    "SWAP info not available" : "Informácia o SWAPe nie je prístupná",
    "Copied!" : "Skopírované!",
    "Not supported!" : "Nepodporované!",
    "Press ⌘-C to copy." : "Pre kopírovanie, stlačte ⌘-C.",
    "Press Ctrl-C to copy." : "Pre kopírovanie, stlačte Ctrl-C.",
    "System" : "Systém",
    "Monitoring" : "Sledovanie",
    "Monitoring app with useful server information" : "Monitorovacia apka s užitočnými informáciami o serveri",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitočné informácie o serveri, ako napríklad vyťaženie CPU, RAM, využitie diskov, počet používateľov, atď.",
    "Operating System:" : "Operačný systém:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Neznámy procesor",
    "Memory:" : "Pamäť:",
    "Server time:" : "Čas na serveri:",
    "Uptime:" : "Doba behu:",
    "Temperature" : "Teplota",
    "Load" : "Záťaž",
    "Memory" : "Pamäť",
    "Disk" : "Disk",
    "Mount:" : "Prípojný bod:",
    "Filesystem:" : "Súborový systém:",
    "Size:" : "Veľkosť:",
    "Available:" : "Dostupné:",
    "Used:" : "Využité:",
    "Files:" : "Súbory:",
    "Storages:" : "Úložiská:",
    "Free Space:" : "Voľné miesto:",
    "Network" : "Sieť",
    "Hostname:" : "Názov servera:",
    "DNS:" : "DNS:",
    "Gateway:" : "Brána:",
    "Status:" : "Stav:",
    "Speed:" : "Rýchlosť:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC adresa:",
    "IPv4:" : "Adresa IPv4:",
    "IPv6:" : "Adresa IPv6:",
    "Active users" : "Aktívni používatelia",
    "Total users:" : "Používateľov celkom:",
    "24 hours:" : "24 hodín:",
    "1 hour:" : "1 hodina:",
    "5 mins:" : "5 minút:",
    "Shares" : "Sprístupnené položky",
    "Users:" : "Používatelia:",
    "Groups:" : "Skupiny:",
    "Links:" : "Odkazy:",
    "Emails:" : "E-maily:",
    "Federated sent:" : "Združené odoslané:",
    "Federated received:" : "Združené prijaté:",
    "Talk conversations:" : "Talk /Rozhovor/ konverzácia",
    "PHP" : "PHP",
    "Version:" : "Verzia:",
    "Memory limit:" : "Obmedzenie pamäte:",
    "Max execution time:" : "Maximálny čas spustenia:",
    "Upload max size:" : "Maximálna veľkosť pre nahratie:",
    "OPcache Revalidate Frequency:" : "Frekvencia opätovného overenia pamäte OPcache:",
    "Extensions:" : "Rozšírenia:",
    "Unable to list extensions" : "Nepodarilo sa zobraziť rozšírenia",
    "Show phpinfo" : "Zobraziť phpinfo",
    "Database" : "Databáza",
    "Type:" : "Typ:",
    "External monitoring tool" : "Externý sledovací nástroj",
    "Use this end point to connect an external monitoring tool:" : "Použite tento prípojný bod pre externý monitorovací nástroj:",
    "Copy" : "Kopírovať",
    "Output in JSON" : "Výstup v JSON",
    "Skip app updates (including app updates will send an external request to the app store)" : "Preskočiť aktualizácie aplikácií (vrátane aktualizácií aplikácií odošle externú požiadavku do obchodu s aplikáciami)",
    "Skip server update" : "Preskočiť aktualizáciu servera",
    "To use an access token, please generate one then set it using the following command:" : "Pre používanie prístupového tokenu ho vygenerujte a potom ho nastavte použitím nasledujúceho príkazu:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Pri dotazovaní na vyššie uvedenú adresu URL potom poslať token s hlavičkou „NC-Token“."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
